@@ -29,7 +29,13 @@ use Const::Exporter enums => [
   FEED_ITEM             => "FEED_ITEM",
   AD_GROUP_FEED         => "AD_GROUP_FEED",
   CAMPAIGN_FEED         => "CAMPAIGN_FEED",
-  AD_GROUP_BID_MODIFIER => "AD_GROUP_BID_MODIFIER"
+  AD_GROUP_BID_MODIFIER => "AD_GROUP_BID_MODIFIER",
+  SHARED_SET            => "SHARED_SET",
+  CAMPAIGN_SHARED_SET   => "CAMPAIGN_SHARED_SET",
+  ASSET                 => "ASSET",
+  CUSTOMER_ASSET        => "CUSTOMER_ASSET",
+  CAMPAIGN_ASSET        => "CAMPAIGN_ASSET",
+  AD_GROUP_ASSET        => "AD_GROUP_ASSET"
 ];
 
 1;
